# coding: utf-8

"""
    perceptic-core-server API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.0.1-SNAPSHOT
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from perceptic_core_client.api.indexing_schedule_resource_api import IndexingScheduleResourceApi


class TestIndexingScheduleResourceApi(unittest.TestCase):
    """IndexingScheduleResourceApi unit test stubs"""

    def setUp(self) -> None:
        self.api = IndexingScheduleResourceApi()

    def tearDown(self) -> None:
        pass

    def test_create_indexing_schedule(self) -> None:
        """Test case for create_indexing_schedule

        Create an indexing schedule
        """
        pass

    def test_delete_indexing_schedule(self) -> None:
        """Test case for delete_indexing_schedule

        Delete an indexing schedule
        """
        pass

    def test_disable_indexing_schedule(self) -> None:
        """Test case for disable_indexing_schedule

        Disable an indexing schedule
        """
        pass

    def test_enable_indexing_schedule(self) -> None:
        """Test case for enable_indexing_schedule

        Enable an indexing schedule
        """
        pass

    def test_get_indexing_schedule(self) -> None:
        """Test case for get_indexing_schedule

        Get an indexing schedule
        """
        pass

    def test_list_indexing_schedules(self) -> None:
        """Test case for list_indexing_schedules

        List indexing schedules
        """
        pass

    def test_list_schedule_executions(self) -> None:
        """Test case for list_schedule_executions

        List schedule execution history
        """
        pass

    def test_update_indexing_schedule(self) -> None:
        """Test case for update_indexing_schedule

        Update an indexing schedule
        """
        pass


if __name__ == '__main__':
    unittest.main()
