# coding: utf-8

"""
    perceptic-core-server API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.0.1-SNAPSHOT
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class RunStatusDto(str, Enum):
    """
    RunStatusDto
    """

    """
    allowed enum values
    """
    QUEUED = 'QUEUED'
    QUEUED_FOR_RESUME = 'QUEUED_FOR_RESUME'
    RUNNING = 'RUNNING'
    PAUSED_FOR_INPUT = 'PAUSED_FOR_INPUT'
    COMPLETED = 'COMPLETED'
    ERROR_REJECTED = 'ERROR_REJECTED'
    ERROR_TIMEOUT = 'ERROR_TIMEOUT'
    ERROR_CLIENT = 'ERROR_CLIENT'
    ERROR_SERVER = 'ERROR_SERVER'
    ERROR_RETRY_LIMIT_EXCEEDED = 'ERROR_RETRY_LIMIT_EXCEEDED'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of RunStatusDto from a JSON string"""
        return cls(json.loads(json_str))


