# coding: utf-8

"""
    perceptic-core-server API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.0.1-SNAPSHOT
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from perceptic_core_client.api.file_system_contents_resource_api import FileSystemContentsResourceApi


class TestFileSystemContentsResourceApi(unittest.TestCase):
    """FileSystemContentsResourceApi unit test stubs"""

    def setUp(self) -> None:
        self.api = FileSystemContentsResourceApi()

    def tearDown(self) -> None:
        pass

    def test_create_folder(self) -> None:
        """Test case for create_folder

        Create Folder
        """
        pass

    def test_download_file(self) -> None:
        """Test case for download_file

        Download
        """
        pass

    def test_get_metadata(self) -> None:
        """Test case for get_metadata

        Get Metadata
        """
        pass

    def test_get_parent_resource(self) -> None:
        """Test case for get_parent_resource

        Get Parent
        """
        pass

    def test_get_signed_url(self) -> None:
        """Test case for get_signed_url

        Signed Url
        """
        pass

    def test_list_files_flattened(self) -> None:
        """Test case for list_files_flattened

        List Files Flattened
        """
        pass

    def test_list_folder_contents(self) -> None:
        """Test case for list_folder_contents

        List
        """
        pass

    def test_upload_file(self) -> None:
        """Test case for upload_file

        Upload File
        """
        pass


if __name__ == '__main__':
    unittest.main()
