# coding: utf-8

"""
    perceptic-core-server API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.0.1-SNAPSHOT
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from perceptic_core_client.api.worker_resource_api import WorkerResourceApi


class TestWorkerResourceApi(unittest.TestCase):
    """WorkerResourceApi unit test stubs"""

    def setUp(self) -> None:
        self.api = WorkerResourceApi()

    def tearDown(self) -> None:
        pass

    def test_api_v1_workers_get(self) -> None:
        """Test case for api_v1_workers_get

        Get Workers
        """
        pass

    def test_api_v1_workers_runs_run_rid_events_sequence_rating_get(self) -> None:
        """Test case for api_v1_workers_runs_run_rid_events_sequence_rating_get

        Get Rating
        """
        pass

    def test_api_v1_workers_runs_run_rid_events_sequence_rating_post(self) -> None:
        """Test case for api_v1_workers_runs_run_rid_events_sequence_rating_post

        Post Rating
        """
        pass

    def test_api_v1_workers_worker_id_get(self) -> None:
        """Test case for api_v1_workers_worker_id_get

        Get Worker Metadata
        """
        pass

    def test_api_v1_workers_worker_id_runs_post(self) -> None:
        """Test case for api_v1_workers_worker_id_runs_post

        Post Worker Run
        """
        pass

    def test_api_v1_workers_worker_id_runs_run_rid_events_get(self) -> None:
        """Test case for api_v1_workers_worker_id_runs_run_rid_events_get

        Get Worker Run Events
        """
        pass

    def test_api_v1_workers_worker_id_runs_run_rid_get(self) -> None:
        """Test case for api_v1_workers_worker_id_runs_run_rid_get

        Get Worker Run
        """
        pass

    def test_api_v1_workers_worker_id_runs_run_rid_resume_post(self) -> None:
        """Test case for api_v1_workers_worker_id_runs_run_rid_resume_post

        Post Resume Run
        """
        pass

    def test_api_v1_workers_worker_id_runs_run_rid_status_get(self) -> None:
        """Test case for api_v1_workers_worker_id_runs_run_rid_status_get

        Get Worker Run Status
        """
        pass

    def test_get_worker_run_events_v2(self) -> None:
        """Test case for get_worker_run_events_v2

        Get Worker Run Events (v2)
        """
        pass


if __name__ == '__main__':
    unittest.main()
