# coding: utf-8

"""
    perceptic-core-server API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.0.1-SNAPSHOT
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from perceptic_core_client.models.model_schema import ModelSchema

class TestModelSchema(unittest.TestCase):
    """ModelSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ModelSchema:
        """Test ModelSchema
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ModelSchema`
        """
        model = ModelSchema()
        if include_optional:
            return ModelSchema(
                title = '',
                description = '',
                id = '',
                schema_location = '',
                location = perceptic_core_client.models.schema_location.SchemaLocation(
                    root_document_uri = '', 
                    pointer_to_location = [
                        ''
                        ], ),
                default_value = None,
                nullable = True,
                read_only = True,
                write_only = True,
                unprocessed_properties = {
                    'key' : null
                    }
            )
        else:
            return ModelSchema(
        )
        """

    def testModelSchema(self):
        """Test ModelSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
