# coding: utf-8

"""
    perceptic-core-server API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.0.1-SNAPSHOT
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from perceptic_core_client.api.user_resource_api import UserResourceApi


class TestUserResourceApi(unittest.TestCase):
    """UserResourceApi unit test stubs"""

    def setUp(self) -> None:
        self.api = UserResourceApi()

    def tearDown(self) -> None:
        pass

    def test_api_v1_users_me_get(self) -> None:
        """Test case for api_v1_users_me_get

        Me
        """
        pass

    def test_api_v1_users_user_subject_get(self) -> None:
        """Test case for api_v1_users_user_subject_get

        Get user by subject
        """
        pass


if __name__ == '__main__':
    unittest.main()
