# coding: utf-8

"""
    perceptic-core-server API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.0.1-SNAPSHOT
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from perceptic_core_client.models.start_execution_response import StartExecutionResponse

class TestStartExecutionResponse(unittest.TestCase):
    """StartExecutionResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> StartExecutionResponse:
        """Test StartExecutionResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `StartExecutionResponse`
        """
        model = StartExecutionResponse()
        if include_optional:
            return StartExecutionResponse(
                task = perceptic_core_client.models.indexing_task_dto.IndexingTaskDto(
                    task_rid = '', 
                    indexer_rid = '', 
                    folder_uri = '', 
                    namespace = '', 
                    target_minimum_version = 56, 
                    settings = {
                        'key' : null
                        }, 
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    status = perceptic_core_client.models.indexing_task_status.IndexingTaskStatus(
                        type = '', ), )
            )
        else:
            return StartExecutionResponse(
        )
        """

    def testStartExecutionResponse(self):
        """Test StartExecutionResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
