# coding: utf-8

"""
    perceptic-core-server API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.0.1-SNAPSHOT
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from perceptic_core_client.models.get_worker_events_v2_response import GetWorkerEventsV2Response

class TestGetWorkerEventsV2Response(unittest.TestCase):
    """GetWorkerEventsV2Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GetWorkerEventsV2Response:
        """Test GetWorkerEventsV2Response
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GetWorkerEventsV2Response`
        """
        model = GetWorkerEventsV2Response()
        if include_optional:
            return GetWorkerEventsV2Response(
                events = [
                    perceptic_core_client.models.worker_event_v2.WorkerEventV2()
                    ],
                next_page_token = perceptic_core_client.models.worker_v2_next_page_token.WorkerV2NextPageToken(
                    offset_for_worker_run_events = 56, 
                    offset_for_input_request_events = 56, )
            )
        else:
            return GetWorkerEventsV2Response(
        )
        """

    def testGetWorkerEventsV2Response(self):
        """Test GetWorkerEventsV2Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
