# coding: utf-8

"""
    perceptic-core-server API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.0.1-SNAPSHOT
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from perceptic_core_client.models.paged_list_file_system_response import PagedListFileSystemResponse

class TestPagedListFileSystemResponse(unittest.TestCase):
    """PagedListFileSystemResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PagedListFileSystemResponse:
        """Test PagedListFileSystemResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PagedListFileSystemResponse`
        """
        model = PagedListFileSystemResponse()
        if include_optional:
            return PagedListFileSystemResponse(
                items = [
                    perceptic_core_client.models.resource_entry_dto.ResourceEntryDto(
                        resource_id = '', 
                        metadata = perceptic_core_client.models.resource_metadata_dto.ResourceMetadataDto(
                            files_system_rid = '', 
                            uri = '', 
                            name = '', 
                            type = 'FILE', 
                            path = '', 
                            extension = '', 
                            size_in_bytes = 56, 
                            last_modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            etag = '', 
                            tags = [
                                ''
                                ], ), )
                    ],
                next_token = ''
            )
        else:
            return PagedListFileSystemResponse(
        )
        """

    def testPagedListFileSystemResponse(self):
        """Test PagedListFileSystemResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
