# coding: utf-8

"""
    perceptic-core-server API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.0.1-SNAPSHOT
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from perceptic_core_client.models.bulk_get_citations_response import BulkGetCitationsResponse

class TestBulkGetCitationsResponse(unittest.TestCase):
    """BulkGetCitationsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> BulkGetCitationsResponse:
        """Test BulkGetCitationsResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `BulkGetCitationsResponse`
        """
        model = BulkGetCitationsResponse()
        if include_optional:
            return BulkGetCitationsResponse(
                citations = [
                    perceptic_core_client.models.citation_api_dto.CitationApiDto(
                        id = '', 
                        input_uri = '', 
                        output_artifact_uri = '', 
                        metadata = perceptic_core_client.models.citation_metadata_api_dto.CitationMetadataApiDto(), )
                    ]
            )
        else:
            return BulkGetCitationsResponse(
        )
        """

    def testBulkGetCitationsResponse(self):
        """Test BulkGetCitationsResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
