# coding: utf-8

"""
    perceptic-core-server API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.0.1-SNAPSHOT
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from perceptic_core_client.models.biotech_analysis_api_dto import BiotechAnalysisApiDto

class TestBiotechAnalysisApiDto(unittest.TestCase):
    """BiotechAnalysisApiDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> BiotechAnalysisApiDto:
        """Test BiotechAnalysisApiDto
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `BiotechAnalysisApiDto`
        """
        model = BiotechAnalysisApiDto()
        if include_optional:
            return BiotechAnalysisApiDto(
                raw_analysis = '',
                compound_data_present = True,
                compounds = [
                    ''
                    ],
                development_stage = '',
                therapeutic_area = '',
                key_findings = [
                    ''
                    ],
                risks = [
                    ''
                    ],
                market_potential = '',
                confidence = 1.337,
                reasoning = '',
                bounding_boxes = [
                    perceptic_core_client.models.image_detection_box_api_dto.ImageDetectionBoxApiDto(
                        x_min = 56, 
                        y_min = 56, 
                        x_max = 56, 
                        y_max = 56, 
                        label = '', 
                        confidence = 1.337, )
                    ],
                page_index = 56,
                character_count = 56
            )
        else:
            return BiotechAnalysisApiDto(
        )
        """

    def testBiotechAnalysisApiDto(self):
        """Test BiotechAnalysisApiDto"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
