# coding: utf-8

"""
    perceptic-core-server API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.0.1-SNAPSHOT
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from perceptic_core_client.api.indexer_resource_api import IndexerResourceApi


class TestIndexerResourceApi(unittest.TestCase):
    """IndexerResourceApi unit test stubs"""

    def setUp(self) -> None:
        self.api = IndexerResourceApi()

    def tearDown(self) -> None:
        pass

    def test_get_indexer(self) -> None:
        """Test case for get_indexer

        Get Indexer
        """
        pass

    def test_list_indexers(self) -> None:
        """Test case for list_indexers

        List Indexers
        """
        pass


if __name__ == '__main__':
    unittest.main()
